@@ -6,7 +6,7 @@
 # the same terms of the Ruby's license.
 #
 # 
-# $Id: rss_check.rb 201 2009-07-29 03:59:18Z znz $
+# $Id$
 # Create : K.S. Sat, 24 Apr 2004 12:10:31 +0900
 #
 
@@ -79,7 +79,7 @@ class RSS_Check
 
     def read_content
       case @uri.scheme
-      when 'http'
+      when 'http', 'https'
         open(@uri){|f|
           if f.content_encoding.any?{|e| /gzip/ =~ e}
             Zlib::GzipReader.new(StringIO.new(f.read)).read || ''
@@ -96,7 +96,7 @@ class RSS_Check
 
     def mtime
       case @uri.scheme
-      when 'http'
+      when 'http', 'https'
         open(@uri){|f|
           f.last_modified || Time.now
         }
@@ -148,20 +148,30 @@ class RSS_Check
   end
 
   def save
+    debug = $DEBUG
+    $DEBUG = false
     @db.transaction{
       @paths.each_with_index{|path, i|
         @db[path] = @rss_files[i]
       }
     } if @db
+  ensure
+    $DEBUG = debug
   end
 
   def load_file file
+    debug = $DEBUG
+    $DEBUG = false
     @db.transaction{
       @db[file]
     } if @db
+  ensure
+    $DEBUG = debug
   end
 
   def clear
+    debug = $DEBUG
+    $DEBUG = false
     if @db
       @db.transaction{
         @db.keys.each{|k|
@@ -169,6 +179,8 @@ class RSS_Check
         }
       }
     end
+  ensure
+    $DEBUG = debug
   end
 end
 
@@ -192,13 +204,11 @@ if $0 == __FILE__
     ARGV.shift || './rss_cache',
     false # false
   )
-  require 'iconv'
   require 'kconv'
-  ic = Iconv.open("EUC-JP", "UTF-8")
   
   rssc.check.each{|e|
     puts e[:about]
-    title = (e[:ccode] == 'UTF-8') ? ic.iconv(e[:title]) : e[:title]
+    title = (e[:ccode] == 'UTF-8') ? e[:title].toeuc : e[:title]
     puts title
   }
   rssc.dump
