@@ -6,7 +6,7 @@
 # the same terms of the Ruby's license.
 #
 #
-# $Id: config.rb 204 2009-08-20 16:45:18Z znz $
+# $Id$
 # Create : K.S. 04/04/17 16:50:33
 #
 #
@@ -34,6 +34,8 @@ module Nadoka
     Client_server_host = nil
     Client_server_pass = 'NadokaPassWord' # or nil
     Client_server_acl  = nil
+    Client_server_ssl_cert_file = nil
+    Client_server_ssl_key_file  = nil
     ACL_Object = nil
     
     # 
@@ -58,7 +60,7 @@ module Nadoka
     Away_Message = 'away'
     Away_Nick    = nil
 
-    Quit_Message = "Quit Nadoka #{::Nadoka::NDK_Version} - http://www.atdot.net/nadoka/"
+    Quit_Message = "Quit Nadoka #{::Nadoka::NDK_Version}"
     
     #
     Channel_info = {}
@@ -139,6 +141,7 @@ module Nadoka
       end
     
     # dirs
+    Default_Plugins_dir = File.expand_path('../../plugins', __FILE__)
     Plugins_dir = './plugins'
     Log_dir     = './log'
     
@@ -178,13 +181,13 @@ module Nadoka
 
     def remove_previous_setting
       # remove setting class
-      klass = ConfigClass.shift
-      while k = ConfigClass.shift
+      base_klass = ConfigClass.shift
+      while klass = ConfigClass.shift
         Object.module_eval{
-          remove_const(k.name)
+          remove_const(klass.name)
         }
       end
-      ConfigClass.push(klass)
+      ConfigClass.push(base_klass)
 
 
       # clear required files
@@ -384,7 +387,7 @@ module Nadoka
       @config = {}
       klass = ConfigClass.last
 
-      klass.ancestors[0..-3].reverse_each{|kl|
+      klass.ancestors[0..klass.ancestors.index(NDK_ConfigBase)].reverse_each{|kl|
         kl.constants.each{|e|
           @config[e.downcase.intern] = klass.const_get(e)
         }
@@ -411,13 +414,17 @@ module Nadoka
     end
     
     def canonical_channel_name ch
-      ch = ch.sub(/^\!.{5}/, '!')
+      ch = ch.toeuc.sub(/^\!.{5}/, '!')
       identical_channel_name ch
     end
 
     def identical_channel_name ch
       # use 4 gsub() because of the compatibility of RFC2813(3.2)
-      ch.toeuc.downcase.tr('[]\\~', '{}|^').tojis.force_encoding('ASCII-8BIT')
+      ch = ch.toeuc.downcase.tr('[]\\~', '{}|^').tojis
+      if ch.respond_to?(:force_encoding)
+        ch.force_encoding(Encoding::ASCII_8BIT)
+      end
+      ch
     end
 
     RName = {        # ('&','#','+','!')
@@ -473,11 +480,18 @@ module Nadoka
       if format.kind_of? Proc
         text = format.call(params)
       elsif format
+        if format.respond_to?(:force_encoding)
+          format.force_encoding(Encoding::ASCII_8BIT)
+        end
         text = format.gsub(/\{([a-z]+)\}|\{prefix\:([a-z]+)\}/){|key|
           if $2
             method = $2.intern
             if msgobj[:orig].respond_to?(:prefix)
-              (msgobj[:orig].prefix || '') =~ /^(.+?)\!(.+?)@(.+)/
+              prefix = msgobj[:orig].prefix || ''
+              if prefix.respond_to?(:force_encoding)
+                prefix.force_encoding(Encoding::ASCII_8BIT)
+              end
+              /^(.+?)\!(.+?)@(.+)/ =~ prefix
               case method
               when :nick
                 $1
@@ -491,7 +505,11 @@ module Nadoka
             end
           else
             if m = msgobj[$1.intern]
-              m
+              if m.respond_to?(:force_encoding)
+                m.dup.force_encoding(Encoding::ASCII_8BIT)
+              else
+                m
+              end
             else
               "!!unknown attribute: #{$1}!!"
             end
