@@ -6,7 +6,7 @@
 # the same terms of the Ruby's license.
 #
 #
-# $Id: logger.rb 189 2008-03-19 10:52:29Z znz $
+# $Id$
 # Create : K.S. 04/05/01 02:04:18
 
 require 'kconv'
@@ -241,7 +241,7 @@ module Nadoka
     def logging msg
       user = @manager.nick_of(msg)
       rch = msg.params[0]
-      ch_ = ch = @config.canonical_channel_name(rch)
+      ch = @config.canonical_channel_name(rch)
 
       msgobj = make_msgobj(msg)
       msgobj[:ch]   = rch  # should be raw
