@@ -6,7 +6,7 @@
 # the same terms of the Ruby's license.
 #
 #
-# $Id: server.rb 243 2010-10-20 16:27:25Z znz $
+# $Id$
 # Create : K.S. 04/04/17 17:00:44
 #
 
@@ -15,6 +15,10 @@ require 'ndk/error'
 require 'ndk/config'
 require 'ndk/server_state'
 require 'ndk/client'
+begin
+  require 'openssl'
+rescue LoadError
+end
 
 module Nadoka
   Cmd = ::RICE::Command
@@ -93,7 +97,7 @@ module Nadoka
           @logger.slog "Connection closed by server. Trying to reconnect."
           
           sleep @config.reconnect_delay
-          retry
+          retry unless @exitting
           
         rescue NDK_ReconnectToServer
           @connected = false
@@ -107,7 +111,7 @@ module Nadoka
           @logger.slog "Reconnect request (no server response, or client request)."
           
           sleep @config.reconnect_delay
-          retry
+          retry unless @exitting
           
         rescue Exception => e
           ndk_error e
@@ -163,8 +167,9 @@ module Nadoka
         case q.command
         when '001'
           break
-        when '433'
+        when '433', '437'
           # Nickname is already in use.
+          # 437 Nick/channel is temporarily unavailable
           nick = @state.nick_succ(q.params[1])
           @state.nick = nick
           send_to_server Cmd.nick(nick)
@@ -173,6 +178,12 @@ module Nadoka
         when 'ERROR'
           msg = "Server login fail!(#{q})"
           @server_thread.raise NDK_ReconnectToServer
+        when '020'
+          # ignore
+        when 'PRIVMSG'
+          # ignore
+        when '004'
+          # ignore
         else
           msg = "Server login fail!(#{q})"
           @logger.slog msg
@@ -341,9 +352,18 @@ module Nadoka
                                    @config.client_server_port)
           @logger.slog "Open Client Server Port: #{@cserver.addr.join(' ')}"
           
+          if @config.client_server_ssl_cert_file && @config.client_server_ssl_key_file
+            context = OpenSSL::SSL::SSLContext.new
+            context.cert = OpenSSL::X509::Certificate.new(File.read(@config.client_server_ssl_cert_file))
+            context.key = OpenSSL::PKey::RSA.new(File.read(@config.client_server_ssl_key_file))
+            @cserver = OpenSSL::SSL::SSLServer.new(@cserver, context)
+            @cserver.start_immediately = false
+          end
+          
           while true
             # wait for client connections
             Thread.start(@cserver.accept){|cc|
+              cc.accept if OpenSSL::SSL::SSLSocket === cc rescue NameError
               client = nil
               begin
                 if !@config.acl_object || @config.acl_object.allow_socket?(cc)
@@ -419,9 +439,12 @@ module Nadoka
       }
       
       begin
-        @server_thread.join
+        sleep
       rescue Interrupt
         @exitting = true
+      rescue Nadoka::NDK_Error
+        @exitting = true
+        raise
       ensure
         @server_thread.kill  if @server_thread  && @server_thread.alive?
         @clients_thread.kill if @clients_thread && @clients_thread.alive?
