@@ -6,21 +6,34 @@
 # the same terms of the Ruby's license.
 #
 # 
-# $Id: version.rb 239 2010-09-29 14:01:28Z znz $
+# $Id$
 # Create : K.S. 04/04/27 16:35:40
 #
 
 module Nadoka
-  NDK_Version  = '0.7.6'
+  VERSION  = '0.9.2'
+  NDK_Version  = VERSION.dup
   NDK_Created  = Time.now
 
-  if /trunk/ =~ '$HeadURL: svn+ssh://rubyforge.org/var/svn/nadoka/trunk/ndk/version.rb $'
+  if File.directory?(File.expand_path('../../.git', __FILE__))
+    git_describe = nil
+    Dir.chdir(File.expand_path('../..', __FILE__)) do
+      git_describe = `git describe --tags --long --dirty=-dt`
+      if $?.success?
+        git_describe = "(#{git_describe.strip})"
+      else
+        git_describe = nil
+      end
+    end
+    NDK_Version.concat("+git#{git_describe}")
+  end
+  if /trunk/ =~ '$HeadURL$'
     NDK_Version.concat('-trunk')
     rev = '-'
     $LOAD_PATH.each{|path|
       path = path + '/ChangeLog'
       if FileTest.exist?(path)
-        if /^\# ChangeLog of Nadoka\(\$Rev: (\d+) \$\)$/ =~ open(path){|f| s = f.gets}
+        if /^\# ChangeLog of Nadoka\(\$Rev: (\d+) \$\)$/ =~ open(path){|f| f.gets}
           rev = "rev: #{$1}"
           break
         end
@@ -35,3 +48,6 @@ module Nadoka
   end
 end
 
+if __FILE__ == $0
+  puts Nadoka::NDK_Version
+end
